@@ -1,12 +1,12 @@
 #! /bin/sh -e
-# /usr/lib/emacsen-common/packages/install/hungarian-l10n
+# /usr/lib/emacsen-common/packages/install/hungarian-l10n-20100223
 
 # Written by Jim Van Zandt <jrv@debian.org>, borrowing heavily
 # from the install scripts for gettext by Santiago Vila
 # <sanvila@ctv.es> and octave by Dirk Eddelbuettel <edd@debian.org>.
 
 FLAVOR=$1
-PACKAGE=hungarian-l10n
+PACKAGE=hungarian-l10n-20100223
 
 if [ ${FLAVOR} = emacs ]; then exit 0; fi
 
