@@ -1,13 +1,13 @@
 #!/bin/sh -e
-# /usr/lib/emacsen-common/packages/remove/hungarian-l10n
+# /usr/lib/emacsen-common/packages/remove/hungarian-l10n-20100223
 
 FLAVOR=$1
-PACKAGE=hungarian-l10n
+PACKAGE=hungarian-l10n-20100223
 
 if [ ${FLAVOR} != emacs ]; then
     if test -x /usr/sbin/install-info-altdir; then
         echo remove/${PACKAGE}: removing Info links for ${FLAVOR}
-        install-info-altdir --quiet --remove --dirname=${FLAVOR} /usr/info/hungarian-l10n.info.gz
+        install-info-altdir --quiet --remove --dirname=${FLAVOR} /usr/info/hungarian-l10n-20100223.info.gz
     fi
 
     echo remove/${PACKAGE}: purging byte-compiled files for ${FLAVOR}
