@@ -2,7 +2,7 @@
 .\" First parameter, NAME, should be all caps
 .\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
 .\" other parameters are allowed: see man(7), man(1)
-.TH HUNGARIAN-L10N SECTION "March 01, 2010"
+.TH HUNGARIAN-L10N-20100223 SECTION "February 23, 2010"
 .\" Please adjust this date whenever revising the manpage.
 .\"
 .\" Some roff macros, for reference:
@@ -16,16 +16,16 @@
 .\" .sp <n>    insert n+1 empty lines
 .\" for manpage-specific macros, see man(7)
 .SH NAME
-hungarian-l10n \- program to do something
+hungarian-l10n-20100223 \- program to do something
 .SH SYNOPSIS
-.B hungarian-l10n
+.B hungarian-l10n-20100223
 .RI [ options ] " files" ...
 .br
 .B bar
 .RI [ options ] " files" ...
 .SH DESCRIPTION
 This manual page documents briefly the
-.B hungarian-l10n
+.B hungarian-l10n-20100223
 and
 .B bar
 commands.
@@ -33,7 +33,7 @@ commands.
 .\" TeX users may be more comfortable with the \fB<whatever>\fP and
 .\" \fI<whatever>\fP escape sequences to invode bold face and italics, 
 .\" respectively.
-\fBhungarian-l10n\fP is a program that...
+\fBhungarian-l10n-20100223\fP is a program that...
 .SH OPTIONS
 These programs follow the usual GNU command line syntax, with long
 options starting with two dashes (`-').
@@ -53,7 +53,7 @@ The programs are documented fully by
 .IR "The Rise and Fall of a Fooish Bar" ,
 available via the Info system.
 .SH AUTHOR
-hungarian-l10n was written by <upstream author>.
+hungarian-l10n-20100223 was written by <upstream author>.
 .PP
-This manual page was written by  -- Laposa Attila <laposa@pannongsm.hu> és Tari László <n900nseries@gmail.com>,
+This manual page was written by unknown <gazdasagi@unknown>,
 for the Debian project (but may be used by others).
